# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v2/trade.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v2/trade.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from systemathics.apis.type.shared.v2 import decimals_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_decimals__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v2/trade.proto\x12 systemathics.apis.type.shared.v2\x1a\x1egoogle/protobuf/wrappers.proto\x1a/systemathics/apis/type/shared/v2/decimals.proto\"\x9b\x03\n\x05Trade\x12<\n\nsize_value\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x00R\tsizeValue\x12i\n\x12size_decimal_value\x18\x02 \x01(\x0b\x32\x39.systemathics.apis.type.shared.v2.NullableUnsignedDecimalH\x00R\x10sizeDecimalValue\x12?\n\x0bprice_value\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValueH\x01R\npriceValue\x12i\n\x13price_decimal_value\x18\x04 \x01(\x0b\x32\x37.systemathics.apis.type.shared.v2.NullableSignedDecimalH\x01R\x11priceDecimalValue\x12\x1c\n\tcondition\x18\x05 \x01(\tR\tcondition\x12\x0e\n\x02id\x18\x06 \x01(\tR\x02idB\x06\n\x04sizeB\x07\n\x05priceB\xd7\x01\n$com.systemathics.apis.type.shared.v2B\nTradeProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.trade_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\nTradeProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_TRADE']._serialized_start=164
  _globals['_TRADE']._serialized_end=575
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/private/v1/identifier_mapping.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/private/v1/identifier_mapping.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import memo_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_memo__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>systemathics/apis/services/private/v1/identifier_mapping.proto\x12%systemathics.apis.services.private.v1\x1a\x1cgoogle/api/annotations.proto\x1a+systemathics/apis/type/shared/v1/memo.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"V\n\x18IdentifierMappingRequest\x12:\n\x04memo\x18\x01 \x01(\x0b\x32&.systemathics.apis.type.shared.v1.MemoR\x04memo\"i\n\x19IdentifierMappingResponse\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier2\xcc\x01\n\x18IdentifierMappingService\x12\xaf\x01\n\x11IdentifierMapping\x12?.systemathics.apis.services.private.v1.IdentifierMappingRequest\x1a@.systemathics.apis.services.private.v1.IdentifierMappingResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/identifiersB\xfe\x01\n)com.systemathics.apis.services.private.v1B\x16IdentifierMappingProtoP\x01\xa2\x02\x04SASP\xaa\x02%Systemathics.Apis.Services.Private.V1\xca\x02&Systemathics\\Apis\\Services\\Private_\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Private::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.private.v1.identifier_mapping_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.private.v1B\026IdentifierMappingProtoP\001\242\002\004SASP\252\002%Systemathics.Apis.Services.Private.V1\312\002&Systemathics\\Apis\\Services\\Private_\\V1\342\0022Systemathics\\Apis\\Services\\Private_\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Private::V1'
  _globals['_IDENTIFIERMAPPINGSERVICE'].methods_by_name['IdentifierMapping']._loaded_options = None
  _globals['_IDENTIFIERMAPPINGSERVICE'].methods_by_name['IdentifierMapping']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/identifiers'
  _globals['_IDENTIFIERMAPPINGREQUEST']._serialized_start=231
  _globals['_IDENTIFIERMAPPINGREQUEST']._serialized_end=317
  _globals['_IDENTIFIERMAPPINGRESPONSE']._serialized_start=319
  _globals['_IDENTIFIERMAPPINGRESPONSE']._serialized_end=424
  _globals['_IDENTIFIERMAPPINGSERVICE']._serialized_start=427
  _globals['_IDENTIFIERMAPPINGSERVICE']._serialized_end=631
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.tick_analytics.v2 import tick_bars_hp_pb2 as systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2


class HpTickBarsServiceStub(object):
    """Called to request tick by tick bars data (high precision).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HpTickBars = channel.unary_stream(
                '/systemathics.apis.services.tick_analytics.v2.HpTickBarsService/HpTickBars',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.FromString,
                )


class HpTickBarsServiceServicer(object):
    """Called to request tick by tick bars data (high precision).
    """

    def HpTickBars(self, request, context):
        """Gets tick by tick bars data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_HpTickBarsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HpTickBars': grpc.unary_stream_rpc_method_handler(
                    servicer.HpTickBars,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick_analytics.v2.HpTickBarsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class HpTickBarsService(object):
    """Called to request tick by tick bars data (high precision).
    """

    @staticmethod
    def HpTickBars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick_analytics.v2.HpTickBarsService/HpTickBars',
            systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick__analytics_dot_v2_dot_tick__bars__hp__pb2.HpTickBarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v2/decimals.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v2/decimals.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/systemathics/apis/type/shared/v2/decimals.proto\x12 systemathics.apis.type.shared.v2\"m\n\rSignedDecimal\x12%\n\x0eunscaled_value\x18\x01 \x01(\x0cR\runscaledValue\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\x12\x1f\n\x0bis_negative\x18\x03 \x01(\x08R\nisNegative\"m\n\x15NullableSignedDecimal\x12J\n\x05value\x18\x01 \x01(\x0b\x32/.systemathics.apis.type.shared.v2.SignedDecimalH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value\"N\n\x0fUnsignedDecimal\x12%\n\x0eunscaled_value\x18\x01 \x01(\x0cR\runscaledValue\x12\x14\n\x05scale\x18\x02 \x01(\x05R\x05scale\"q\n\x17NullableUnsignedDecimal\x12L\n\x05value\x18\x01 \x01(\x0b\x32\x31.systemathics.apis.type.shared.v2.UnsignedDecimalH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_valueB\xda\x01\n$com.systemathics.apis.type.shared.v2B\rDecimalsProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.decimals_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\rDecimalsProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_SIGNEDDECIMAL']._serialized_start=85
  _globals['_SIGNEDDECIMAL']._serialized_end=194
  _globals['_NULLABLESIGNEDDECIMAL']._serialized_start=196
  _globals['_NULLABLESIGNEDDECIMAL']._serialized_end=305
  _globals['_UNSIGNEDDECIMAL']._serialized_start=307
  _globals['_UNSIGNEDDECIMAL']._serialized_end=385
  _globals['_NULLABLEUNSIGNEDDECIMAL']._serialized_start=387
  _globals['_NULLABLEUNSIGNEDDECIMAL']._serialized_end=500
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v2/time_interval.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v2/time_interval.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/type/shared/v2/time_interval.proto\x12 systemathics.apis.type.shared.v2\x1a\x1bgoogle/type/timeofday.proto\"x\n\x0cTimeInterval\x12\x35\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDayR\tstartTime\x12\x31\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayR\x07\x65ndTimeB\xde\x01\n$com.systemathics.apis.type.shared.v2B\x11TimeIntervalProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V2\xca\x02 Systemathics\\Apis\\Type\\Shared\\V2\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v2.time_interval_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v2B\021TimeIntervalProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V2\312\002 Systemathics\\Apis\\Type\\Shared\\V2\342\002,Systemathics\\Apis\\Type\\Shared\\V2\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V2'
  _globals['_TIMEINTERVAL']._serialized_start=119
  _globals['_TIMEINTERVAL']._serialized_end=239
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/type/shared/v1/field.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/type/shared/v1/field.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,systemathics/apis/type/shared/v1/field.proto\x12 systemathics.apis.type.shared.v1*\xf1\x04\n\x05\x46ield\x12\x15\n\x11\x46IELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46IELD_OPEN_PRICE\x10\x01\x12\x13\n\x0f\x46IELD_OPEN_SIZE\x10\x02\x12\x15\n\x11\x46IELD_CLOSE_PRICE\x10\x03\x12\x14\n\x10\x46IELD_CLOSE_SIZE\x10\x04\x12\x13\n\x0f\x46IELD_LOW_PRICE\x10\x05\x12\x12\n\x0e\x46IELD_LOW_SIZE\x10\x06\x12\x14\n\x10\x46IELD_HIGH_PRICE\x10\x07\x12\x13\n\x0f\x46IELD_HIGH_SIZE\x10\x08\x12\x15\n\x11\x46IELD_TRADE_PRICE\x10\t\x12\x14\n\x10\x46IELD_TRADE_SIZE\x10\n\x12\x1b\n\x17\x46IELD_TRADING_CONDITION\x10\x0b\x12\x15\n\x11\x46IELD_TRADE_COUNT\x10\x0c\x12\x19\n\x15\x46IELD_TRADE_OTC_PRICE\x10\r\x12\x18\n\x14\x46IELD_TRADE_OTC_SIZE\x10\x0e\x12\x19\n\x15\x46IELD_TRADE_OTC_COUNT\x10\x0f\x12\x10\n\x0c\x46IELD_VOLUME\x10\x10\x12\x17\n\x13\x46IELD_VWAP_OFFICIAL\x10\x11\x12\x19\n\x15\x46IELD_VWAP_ELECTRONIC\x10\x12\x12\x1b\n\x17\x46IELD_THEORETICAL_PRICE\x10\x13\x12\x1a\n\x16\x46IELD_THEORETICAL_SIZE\x10\x14\x12\x15\n\x11\x46IELD_UPPER_PRICE\x10\x15\x12\x15\n\x11\x46IELD_LOWER_PRICE\x10\x16\x12\x13\n\x0f\x46IELD_VARIATION\x10\x17\x12\x1e\n\x1a\x46IELD_VARIATION_PERCENTAGE\x10\x18\x12\x12\n\x0e\x46IELD_TRADE_ID\x10\x19\x42\xd7\x01\n$com.systemathics.apis.type.shared.v1B\nFieldProtoP\x01\xa2\x02\x04SATS\xaa\x02 Systemathics.Apis.Type.Shared.V1\xca\x02 Systemathics\\Apis\\Type\\Shared\\V1\xe2\x02,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\xea\x02$Systemathics::Apis::Type::Shared::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.type.shared.v1.field_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n$com.systemathics.apis.type.shared.v1B\nFieldProtoP\001\242\002\004SATS\252\002 Systemathics.Apis.Type.Shared.V1\312\002 Systemathics\\Apis\\Type\\Shared\\V1\342\002,Systemathics\\Apis\\Type\\Shared\\V1\\GPBMetadata\352\002$Systemathics::Apis::Type::Shared::V1'
  _globals['_FIELD']._serialized_start=83
  _globals['_FIELD']._serialized_end=708
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/daily/v1/daily_calendars.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/daily/v1/daily_calendars.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9systemathics/apis/services/daily/v1/daily_calendars.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xba\x01\n\x15\x44\x61ilyCalendarsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"`\n\x16\x44\x61ilyCalendarsResponse\x12\x46\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x32.systemathics.apis.services.daily.v1.DailyCalendarR\x04\x64\x61ta\"\xa1\x01\n\rDailyCalendar\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x1d\n\nis_holiday\x18\x04 \x01(\x08R\tisHoliday\x12\x14\n\x05score\x18\x05 \x01(\x01R\x05score2\xc0\x01\n\x15\x44\x61ilyCalendarsService\x12\xa6\x01\n\x0e\x44\x61ilyCalendars\x12:.systemathics.apis.services.daily.v1.DailyCalendarsRequest\x1a;.systemathics.apis.services.daily.v1.DailyCalendarsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/daily/calendarsB\xef\x01\n\'com.systemathics.apis.services.daily.v1B\x13\x44\x61ilyCalendarsProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_calendars_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\023DailyCalendarsProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYCALENDARSSERVICE'].methods_by_name['DailyCalendars']._loaded_options = None
  _globals['_DAILYCALENDARSSERVICE'].methods_by_name['DailyCalendars']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/daily/calendars'
  _globals['_DAILYCALENDARSREQUEST']._serialized_start=258
  _globals['_DAILYCALENDARSREQUEST']._serialized_end=444
  _globals['_DAILYCALENDARSRESPONSE']._serialized_start=446
  _globals['_DAILYCALENDARSRESPONSE']._serialized_end=542
  _globals['_DAILYCALENDAR']._serialized_start=545
  _globals['_DAILYCALENDAR']._serialized_end=706
  _globals['_DAILYCALENDARSSERVICE']._serialized_start=709
  _globals['_DAILYCALENDARSSERVICE']._serialized_end=901
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/indices/v1/components.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'systemathics/apis/services/indices/v1/components.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6systemathics/apis/services/indices/v1/components.proto\x12%systemathics.apis.services.indices.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"a\n\x11\x43omponentsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\"f\n\x12\x43omponentsResponse\x12P\n\ncomponents\x18\x01 \x03(\x0b\x32\x30.systemathics.apis.services.indices.v1.ComponentR\ncomponents\"q\n\tComponent\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06weight\x18\x02 \x01(\x01R\x06weight2\xba\x01\n\x11\x43omponentsService\x12\xa4\x01\n\nComponents\x12\x38.systemathics.apis.services.indices.v1.ComponentsRequest\x1a\x39.systemathics.apis.services.indices.v1.ComponentsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/staticdata/componentsB\xf5\x01\n)com.systemathics.apis.services.indices.v1B\x0f\x43omponentsProtoP\x01\xa2\x02\x04SASI\xaa\x02%Systemathics.Apis.Services.Indices.V1\xca\x02%Systemathics\\Apis\\Services\\Indices\\V1\xe2\x02\x31Systemathics\\Apis\\Services\\Indices\\V1\\GPBMetadata\xea\x02)Systemathics::Apis::Services::Indices::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.indices.v1.components_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.systemathics.apis.services.indices.v1B\017ComponentsProtoP\001\242\002\004SASI\252\002%Systemathics.Apis.Services.Indices.V1\312\002%Systemathics\\Apis\\Services\\Indices\\V1\342\0021Systemathics\\Apis\\Services\\Indices\\V1\\GPBMetadata\352\002)Systemathics::Apis::Services::Indices::V1'
  _globals['_COMPONENTSSERVICE'].methods_by_name['Components']._loaded_options = None
  _globals['_COMPONENTSSERVICE'].methods_by_name['Components']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/staticdata/components'
  _globals['_COMPONENTSREQUEST']._serialized_start=178
  _globals['_COMPONENTSREQUEST']._serialized_end=275
  _globals['_COMPONENTSRESPONSE']._serialized_start=277
  _globals['_COMPONENTSRESPONSE']._serialized_end=379
  _globals['_COMPONENT']._serialized_start=381
  _globals['_COMPONENT']._serialized_end=494
  _globals['_COMPONENTSSERVICE']._serialized_start=497
  _globals['_COMPONENTSSERVICE']._serialized_end=683
# @@protoc_insertion_point(module_scope)
